summaryrefslogtreecommitdiff
path: root/gst/gstplugin.h
diff options
context:
space:
mode:
authorThomas Vander Stichele <thomas@apestaart.org>2005-09-03 17:00:52 +0000
committerThomas Vander Stichele <thomas@apestaart.org>2005-09-03 17:00:52 +0000
commit25169fe885f1e3828cb2dab7fd0f032e5620e128 (patch)
tree80d7ce26ce52861f0ff90171a2dce48a6ce0dbd7 /gst/gstplugin.h
parent91cd48e4b72af1f5d1724aa3ad44eabca292babb (diff)
add a source plugin description field, to represent the source module this plugin is a part of. By default GST_PLUGI...
Original commit message from CVS: add a source plugin description field, to represent the source module this plugin is a part of. By default GST_PLUGIN_DEFINE will set it to PACKAGE, which is automake's idea of the name of the source project.
Diffstat (limited to 'gst/gstplugin.h')
-rw-r--r--gst/gstplugin.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/gst/gstplugin.h b/gst/gstplugin.h
index cd8710248..fe20d2c8f 100644
--- a/gst/gstplugin.h
+++ b/gst/gstplugin.h
@@ -58,10 +58,11 @@ struct _GstPluginDesc {
gchar *name; /* unique name of plugin */
gchar *description; /* description of plugin */
GstPluginInitFunc plugin_init; /* pointer to plugin_init function */
- GstPluginExitFunc plugin_exit; /* pointer to exiting function */
+ GstPluginExitFunc plugin_exit; /* pointer to plugin_exit function */
gchar *version; /* version of the plugin */
gchar *license; /* effective license of plugin */
- gchar *package; /* package plugin belongs to */
+ gchar *source; /* source module plugin belongs to */
+ gchar *package; /* shipped package plugin belongs to */
gchar *origin; /* URL to provider of plugin */
gpointer _gst_reserved[GST_PADDING];
@@ -90,6 +91,7 @@ GST_PLUGIN_EXPORT GstPluginDesc gst_plugin_desc = { \
NULL, \
version, \
license, \
+ PACKAGE, \
package, \
origin, \
GST_PADDING_INIT \
@@ -108,6 +110,7 @@ _gst_plugin_static_init__ ##init (void) \
NULL, \
version, \
license, \
+ PACKAGE, \
package, \
origin, \
GST_PADDING_INIT \
@@ -132,6 +135,7 @@ G_CONST_RETURN gchar* gst_plugin_get_description (GstPlugin *plugin);
G_CONST_RETURN gchar* gst_plugin_get_filename (GstPlugin *plugin);
G_CONST_RETURN gchar* gst_plugin_get_version (GstPlugin *plugin);
G_CONST_RETURN gchar* gst_plugin_get_license (GstPlugin *plugin);
+G_CONST_RETURN gchar* gst_plugin_get_source (GstPlugin *plugin);
G_CONST_RETURN gchar* gst_plugin_get_package (GstPlugin *plugin);
G_CONST_RETURN gchar* gst_plugin_get_origin (GstPlugin *plugin);
GModule * gst_plugin_get_module (GstPlugin *plugin);